@@ -3,7 +3,6 @@ knit_params_get <- function(input_lines, params) {
 
   # read the default parameters and extract them into a named list
   knit_params <- knitr::knit_params(input_lines)
-  if (packageVersion('yaml') < '2.1.14') knit_params <- mark_utf8(knit_params)
   default_params <- list()
   for (param in knit_params) {
     default_params[param$name] <- list(param$value)
@@ -110,7 +109,13 @@ params_value_from_ui <- function(inputControlFn, value, uivalue) {
         # Empty POSIXct
         Sys.time()[-1]
       } else {
-        as.POSIXct(uivalue)
+        tryCatch({
+          as.POSIXct(uivalue)
+        }, error = function(e) {
+          # Unparseable time values produce NULL and float to the default.
+          # This happens most frequently when actively editing a date/time.
+          NULL
+        })
       }
     } else {
       uivalue
@@ -250,17 +255,16 @@ knit_params_ask <- function(file = NULL,
                             params = NULL,
                             shiny_args = NULL,
                             save_caption = "Save",
-                            encoding = getOption("encoding")) {
+                            encoding = "UTF-8") {
 
   if (is.null(input_lines)) {
     if (is.null(file)) {
       stop("knit_params_ask must have a non-NULL file or input_lines parameter")
     }
-    input_lines <- read_lines_utf8(file, encoding)
+    input_lines <- read_utf8(file, encoding)
   }
 
   knit_params <- knitr::knit_params(input_lines)
-  if (packageVersion('yaml') < '2.1.14') knit_params <- mark_utf8(knit_params)
 
   ## Input validation on params (checks shared with render)
   if (!is.null(params)) {
@@ -440,26 +444,28 @@ knit_params_ask <- function(file = NULL,
     })
   }
 
-  contents <- shiny::tags$div(
+  contents <- tags$div(
       shiny::fluidRow(shiny::column(12, lapply(configurable, function(param) {
         shiny::uiOutput(paste0("ui_", param$name))
       }))), class = "container-fluid")
 
   if (length(unconfigurable) > 0) {
-    skipped <- shiny::tags$div(shiny::tags$strong("Note:"),
-                            "The following parameters cannot be customized:",
-                            paste(lapply(unconfigurable, function(param) { param$name }), collapse = ", "))
+    skipped <- tags$div(tags$strong("Note:"),
+                        "The following parameters cannot be customized:",
+                        paste(lapply(unconfigurable, function(param) param$name), collapse = ", "))
     contents <- shiny::tagAppendChildren(contents, shiny::fluidRow(shiny::column(12, skipped)))
   }
-  footer <- shiny::tags$div(
-      shiny::tags$div(
-          shiny::fluidRow(shiny::column(12,
-                                        shiny::actionButton("save", save_caption, class = "btn-primary navbar-btn pull-right"),
-                                        shiny::actionButton("cancel","Cancel", class = "navbar-btn pull-right"))),
-          class = "container-fluid"),
-      class = "navbar navbar-default navbar-fixed-bottom")
+  footer <- tags$div(
+    tags$div(
+      shiny::fluidRow(shiny::column(
+        12,
+        shiny::actionButton("save", save_caption, class = "btn-primary navbar-btn pull-right"),
+        shiny::actionButton("cancel","Cancel", class = "navbar-btn pull-right")
+      )),
+      class = "container-fluid"),
+    class = "navbar navbar-default navbar-fixed-bottom")
 
-  style <- shiny::tags$style(
+  style <- tags$style(
       # Our controls are wiiiiide.
       ".container-fluid .shiny-input-container { width: auto; }",
       # Prevent the save/cancel buttons from squashing together.
@@ -469,13 +475,13 @@ knit_params_ask <- function(file = NULL,
       "body { padding-bottom: 70px; }"
                              )
   ## Escape is "cancel" and Enter is "save".
-  script <- shiny::tags$script(shiny::HTML("$(document).keyup(function(e) {\n",
-                                           "if (e.which == 13) { $('#save').click(); } // enter\n",
-                                           "if (e.which == 27) { $('#cancel').click(); } // esc\n",
-                                           "});"
-                                           ))
+  script <- tags$script(HTML("$(document).keyup(function(e) {\n",
+                             "if (e.which == 13) { $('#save').click(); } // enter\n",
+                             "if (e.which == 27) { $('#cancel').click(); } // esc\n",
+                             "});"
+  ))
   ui <- shiny::bootstrapPage(
-      shiny::tags$head(style, script),
+      tags$head(style, script),
       contents,
       footer)
 
