@@ -92,7 +92,7 @@ yaml_load <- function(...) yaml::yaml.load(..., eval.expr = TRUE)
 yaml_load_file <- function(input, ...) yaml_load(read_utf8(input), ...)
 
 file_name_without_shell_chars <- function(file) {
-  name <- gsub(.shell_chars_regex, '_', basename(file))
+  name <- gsub(.shell_chars_regex, '-', basename(file))
   dir <- dirname(file)
   if (nzchar(dir) && !identical(dir, "."))
     file.path(dir, name)
@@ -173,7 +173,8 @@ highlighters <- function() {
     "monochrome",
     "espresso",
     "zenburn",
-    "haddock")
+    "haddock",
+    "breezedark")
 }
 
 merge_lists <- function(base_list, overlay_list, recursive = TRUE) {
